@@ -1,8 +1,8 @@
 import json
 from math import cos, sin, sqrt
 from time import time
-from pydantic import BaseModel
-from typing import Any, Dict, Iterable, List, Optional
+from pydantic import BaseModel, Field
+from typing import Any, Dict, List, Optional, Sequence
 
 from .config import Config as LidiaConfig
 from .mytypes import VectorModel, IntFlagModel
@@ -37,10 +37,15 @@ class NED(VectorModel):
 
 class Controls(VectorModel):
     stick_right: float = 0
+    """Control stick input to roll right, between -1 and 1"""
     stick_pull: float = 0
+    """Control stick input to pitch up, between -1 and 1"""
     throttle: float = 0
+    """Engine power input, between 0 and 1"""
     pedals_right: float = 0
+    """Pedals input to yaw right, between -1 and 1"""
     collective_up: float = 0
+    """Collective input to increase lift, between 0 and 1"""
 
 
 class Borders(BaseModel):
@@ -72,71 +77,19 @@ class Instruments(BaseModel):
     """Radio altimeter"""
 
 
-class AircraftState(BaseModel):
-    """Full state of displayed aircraft"""
+class CASMessage(BaseModel):
+    msg_id: int
+    blinking: bool
 
-    ned: Optional[NED] = None
-    """Position in local horizon coordinate system, in meters"""
-    att: Optional[Attitude] = None
-    """Aircraft attitude, in radians"""
-    v_body: Optional[XYZ] = None
-    """Velocity in body frame, in meters per second"""
-    v_ned: Optional[NED] = None
-    """Velocity in local horizon coordinate system, in meters per second"""
-    ctrl: Optional[Controls] = None
-    """Current control inceptors position"""
-    trgt: Optional[Controls] = None
-    """Target inceptors position"""
-    trim: Optional[Controls] = None
-    """Controls trim"""
-    brdr: Optional[Borders] = None
-    """Task borders for inceptors"""
-    btn: Optional[Buttons] = None
-    """Currently pressed buttons"""
-    instr: Optional[Instruments] = None
-    """Instrument values"""
-    t_boot: Optional[int] = None
-    """Time from the start of simulation, in milliseconds"""
 
-    class Config:
-        json_encoders = {
-            VectorModel: VectorModel.smol,
-            Borders: Borders.smol,
-            IntFlagModel: IntFlagModel.smol,
-        }
+class CAS(BaseModel):
+    """Crew Alerting System state"""
+    msgs: List[CASMessage]
 
-    def smol(self) -> Dict[str, Any]:
-        """Return self as dictionary with SMOL-defined keys"""
-        # HACK: JSON roundtrip is required, because there is no encoder configuration for .dict()
-        return json.loads(self.json(models_as_dict=False, exclude={f for f in self.__fields__ if getattr(self, f) is None}))
 
-    @classmethod
-    def from_smol(cls, smol: dict) -> 'AircraftState':
-        state = cls()
-        for name in ['ned', 'v_ned']:
-            if name in smol:
-                setattr(state, name, NED.from_list(smol[name]))
-        if 'att' in smol:
-            state.att = Attitude.from_list(smol['att'])
-        if 'v_body' in smol:
-            state.v_body = XYZ.from_list(smol['v_body'])
-        for name in ['ctrl', 'trgt', 'trim']:
-            if name in smol:
-                setattr(state, name, Controls.from_list(smol[name]))
-        # TODO: Borders
-        if 'btn' in smol:
-            state.btn = Buttons.from_list(smol[name])
-        if 'instr' in smol:
-            state.instr = Instruments()
-            for name in ['ias', 'gs', 'alt', 'qnh', 'alt']:
-                if name in smol['instr']:
-                    setattr(state, name, smol['instr'][name])
-        if 't_boot' in smol:
-            state.t_boot = smol['t_boot']
-
-        return state
-
-    def _matmul(matrix: Iterable[float], multiplicand: Iterable[float]) -> List[float]:
+class Transforms:
+    @staticmethod
+    def _matmul(matrix: Sequence[float], multiplicand: Sequence[float]) -> List[float]:
         """Multiply 3x3 matrix by 3-element vector or 3x3 matrix"""
         assert len(matrix) == 9
         assert len(multiplicand) == 3 or len(multiplicand) == 9
@@ -148,7 +101,7 @@ class AircraftState(BaseModel):
                 x * m[3] + y * m[4] + z * m[5],
                 x * m[6] + y * m[7] + z * m[8],
             ]
-        if len(multiplicand) == 9:
+        elif len(multiplicand) == 9:
             m = matrix
             n = multiplicand
             # aut
@@ -157,8 +110,11 @@ class AircraftState(BaseModel):
                 m[3] * n[0] + m[4] * n[3] + m[5] * n[6], m[3] * n[1] + m[4] * n[4] + m[5] * n[7], m[3] * n[2] + m[4] * n[5] + m[5] * n[8],  # noqa
                 m[6] * n[0] + m[7] * n[3] + m[8] * n[6], m[6] * n[1] + m[7] * n[4] + m[8] * n[7], m[6] * n[2] + m[7] * n[5] + m[8] * n[8],  # noqa
             ]
+        else:
+            raise RuntimeError('Unreachable, check assertions')
 
-    def _transpose(matrix: Iterable[float]) -> List[float]:
+    @staticmethod
+    def _transpose(matrix: Sequence[float]) -> List[float]:
         """Transpose 3x3 matrix"""
         assert len(matrix) == 9
         m = matrix
@@ -168,6 +124,7 @@ class AircraftState(BaseModel):
             m[2], m[5], m[8],
         ]
 
+    @staticmethod
     def _rotmat(att: Attitude) -> List[float]:
         """Create 3x3 rotation matrix transforming body-frame vectors to outside frame"""
         s, c = sin(att.roll), cos(att.roll)
@@ -189,7 +146,67 @@ class AircraftState(BaseModel):
             0, 0, 1
         ]
 
-        return AircraftState._matmul(rot_yaw, AircraftState._matmul(rot_pitch, rot_roll))
+        return Transforms._matmul(rot_yaw, Transforms._matmul(rot_pitch, rot_roll))
+
+
+class AircraftData(BaseModel):
+    """Non-recursive state of displayed aircraft"""
+
+    ned: Optional[NED] = None
+    """Position in local horizon coordinate system, in meters"""
+    att: Optional[Attitude] = None
+    """Aircraft attitude, in radians"""
+    v_body: Optional[XYZ] = None
+    """Velocity in body frame, in meters per second"""
+    v_ned: Optional[NED] = None
+    """Velocity in local horizon coordinate system, in meters per second"""
+    ctrl: Optional[Controls] = None
+    """Current control inceptors position"""
+    brdr: Optional[Borders] = None
+    """Task borders for inceptors"""
+    btn: Optional[Buttons] = None
+    """Currently pressed buttons"""
+    instr: Optional[Instruments] = None
+    """Instrument values"""
+    t_boot: Optional[int] = None
+    """Time from the start of simulation, in milliseconds"""
+
+    class Config:
+        json_encoders = {
+            VectorModel: VectorModel.smol,
+            Borders: Borders.smol,
+            IntFlagModel: IntFlagModel.smol,
+        }
+
+    def smol(self) -> Dict[str, Any]:
+        """Return self as dictionary with SMOL-defined keys"""
+        # HACK: JSON roundtrip is required, because there is no encoder configuration for .dict()
+        return json.loads(self.json(models_as_dict=False, exclude={f for f in self.__fields__ if (getattr(self, f) is None or f in ['trgt', 'trim'])}))
+
+    @classmethod
+    def from_smol(cls, smol: dict) -> 'AircraftData':
+        state = cls()
+        for name in ['ned', 'v_ned']:
+            if name in smol:
+                setattr(state, name, NED.from_list(smol[name]))
+        if 'att' in smol:
+            state.att = Attitude.from_list(smol['att'])
+        if 'v_body' in smol:
+            state.v_body = XYZ.from_list(smol['v_body'])
+        if 'ctrl' in smol:
+            state.ctrl = Controls.from_list(smol['ctrl'])
+        # TODO: Borders
+        if 'btn' in smol:
+            state.btn = Buttons.from_list(smol['btn'])
+        if 'instr' in smol:
+            state.instr = Instruments()
+            for name in ['ias', 'gs', 'alt', 'qnh', 'alt']:
+                if name in smol['instr']:
+                    setattr(state, name, smol['instr'][name])
+        if 't_boot' in smol:
+            state.t_boot = smol['t_boot']
+
+        return state
 
     def xyz2ned(self, vec: XYZ) -> NED:
         """Transform from body frame vector to outside frame coordinates
@@ -198,7 +215,7 @@ class AircraftState(BaseModel):
         if self.att is None:
             return NED.from_list([vec.x, vec.y, vec.z])
         else:
-            return NED.from_list(AircraftState._matmul(AircraftState._rotmat(self.att), [vec.x, vec.y, vec.z]))
+            return NED.from_list(Transforms._matmul(Transforms._rotmat(self.att), [vec.x, vec.y, vec.z]))
 
     def ned2xyz(self, vec: NED) -> XYZ:
         """Transform from outside frame to body frame coordinates
@@ -207,7 +224,7 @@ class AircraftState(BaseModel):
         if self.att is None:
             return XYZ.from_list([vec.north, vec.east, vec.down])
         else:
-            return XYZ.from_list(AircraftState._matmul(AircraftState._transpose(AircraftState._rotmat(self.att)), [vec.north, vec.east, vec.down]))
+            return XYZ.from_list(Transforms._matmul(Transforms._transpose(Transforms._rotmat(self.att)), [vec.north, vec.east, vec.down]))
 
     def model_instruments(self, config: LidiaConfig):
         """Generate values for instruments based on known parameters and configuration"""
@@ -265,12 +282,64 @@ class AircraftState(BaseModel):
             self.t_boot = int((time() - config.start_time) * 1000)
 
 
+class AircraftState(AircraftData):
+    """Full aircraft state containing target and trim condition
+
+    Split from `AircraftData` to prevent recursive definition"""
+
+    trgt: Optional[AircraftData] = None
+    """Target values for pilot to track"""
+    trim: Optional[AircraftData] = None
+    """Trim values"""
+
+    def smol(self) -> Dict[str, Any]:
+        data = super().smol()
+        if self.trgt is not None:
+            data['trgt'] = self.trgt.smol()
+        if self.trim is not None:
+            data['trim'] = self.trim.smol()
+        return data
+
+    @classmethod
+    def from_smol(cls, smol: dict) -> 'AircraftState':
+        state = cls(**super().from_smol(smol).dict())
+        for name in ['trgt', 'trim']:
+            if name in smol:
+                # For backwards compatibility
+                if smol[name] is List:
+                    # TODO: Some warning when logging setup available
+                    smol[name] = {'ctrl': {name: smol[name]}}
+                setattr(state, name, AircraftData.from_smol(smol[name]))
+
+        return state
+
+
 if __name__ == '__main__':
     # run this from src/ folder like this: python -m lidia.aircraft
+    import os
+
     config = LidiaConfig()
     state = AircraftState()
-    state.ned = NED.from_list([1, 2, 3])
-    state.att = Attitude.from_list([4, 5, 6])
-    state.v_body = XYZ.from_list([5, 0, 0])
-    state.model_instruments(config)
+    state.ned = NED.from_list([0.0, 0.0, 0.0])
+    state.att = Attitude.from_list([0.0, 0.0, 0.0])
+    state.v_body = XYZ.from_list([0.0, 0.0, 0.0])
+    state.v_ned = NED.from_list([0.0, 0.0, 0.0])
+    state.ctrl = Controls.from_list([0.0, 0.0, 0.0, 0.0, 0.0])
+    state.trgt = AircraftData()
+    state.trgt.ctrl = Controls.from_list([0.0, 0.0, 0.0, 0.0, 0.0])
+    state.t_boot = 0x10000000
+    # state.model_instruments(config)
     print(state.smol())
+    import msgpack
+    packer = msgpack.Packer(use_single_float=False)
+    data_double = packer.pack(state.smol())
+    packer = msgpack.Packer(use_single_float=True)
+    data_float = packer.pack(state.smol())
+    data = data_double[:0x21] + data_float[0x15:]
+    for i, b in enumerate(data):
+        print(f'0x{b:02X}, ', end='')
+    print()
+    os.makedirs('lidia/data', exist_ok=True)
+    with open('lidia/data/aircraft.bin', 'wb') as out:
+        out.write(data)
+    print(msgpack.unpackb(data))
