@@ -39,13 +39,14 @@ def run_server(q: Queue, args: Namespace, config: Config):
     # specifying just local path breaks when run as a module
     root_path = path.abspath(path.dirname(__file__))
     static_files = {
-        '/': {'content_type': 'text/html', 'filename': path.join(root_path, 'index.html')},
+        '/': {'content_type': 'text/html', 'filename': path.join(root_path, 'rpctask.html')},
+        '/info': {'content_type': 'text/html', 'filename': path.join(root_path, 'info.html')},
+        '/rpctask': {'content_type': 'text/html', 'filename': path.join(root_path, 'rpctask.html')},
         '/pfd': {'content_type': 'text/html', 'filename': path.join(root_path, 'pfd.html')},
         '/approach': {'content_type': 'text/html', 'filename': path.join(root_path, 'approach.html')},
         '/static': path.join(root_path, 'static'),
     }
 
-    # TODO: on received `config_request` send `config` event with config dict
     sio = socketio.Server()
 
     @sio.on('config_request')
