@@ -1,6 +1,6 @@
 """looping simulation demonstrating GUI"""
 from argparse import _SubParsersAction, ArgumentDefaultsHelpFormatter, ArgumentError, ArgumentParser, Namespace
-from math import cos, pi, sin
+from math import pi, sin
 from multiprocessing import Queue
 from time import sleep, time
 from typing import Tuple
@@ -50,11 +50,9 @@ def run(q: Queue, args: Namespace, config: Config):
     def current_phase(): return (time() / args.period) % 1
 
     last_trim = Controls()
-    start_time = time()
 
     while True:
         state = AircraftState()
-
         state.ned = NED()
         state.ned.down = -args.alt_zero - args.alt_change * val(0.75)
 
@@ -65,18 +63,26 @@ def run(q: Queue, args: Namespace, config: Config):
 
         state.v_body = XYZ()
         state.v_body.x = 15 + 2.5 * val(0.5)
+        state.v_body.y = 1 * val(0.65)
+        state.v_body.z = 2 * val(0.25)
 
         state.v_ned = state.xyz2ned(state.v_body)
 
         state.ctrl = Controls()
         state.ctrl.stick_pull = val(0.1)
         state.ctrl.stick_right = val(0.35)
+        state.ctrl.pedals_right = val(0.6)
         state.ctrl.collective_up = 0.3 + 0.5 * (val(0.2) + outside_offset)
 
-        state.trgt = Controls()
-        state.trgt.stick_pull = val(0.55)
-        state.trgt.stick_right = val(0.3)
-        state.trgt.collective_up = 0.3 + 0.5 * (val(0.4) + outside_offset)
+        state.trgt = AircraftData()
+        state.trgt.ctrl = Controls()
+        state.trgt.ctrl.stick_pull = val(0.55)
+        state.trgt.ctrl.stick_right = val(0.3)
+        state.trgt.ctrl.pedals_right = val(0.5)
+        state.trgt.ctrl.collective_up = 0.3 + 0.5 * (val(0.4) + outside_offset)
+        state.trgt.att = Attitude()
+        state.trgt.att.roll = 0.3 * val(0.35)
+        state.trgt.att.pitch = 0.3 * val(0.1)
 
         state.btn = Buttons()
         if cycle_index() == 1 and args.trim:
@@ -90,7 +96,8 @@ def run(q: Queue, args: Namespace, config: Config):
         if state.btn.cyc_ftr:
             last_trim.stick_right = state.ctrl.stick_right
             last_trim.stick_pull = state.ctrl.stick_pull
-        state.trim = last_trim
+        state.trim = AircraftData()
+        state.trim.ctrl = last_trim
 
         state.brdr = Borders()
         if cycle_index() == 2 and args.borders:
